/* Header labels */
label.primary-label {
    font-size: 16pt;
    font-weight: bold;
    color: @accent_color;
    padding: 12px;
}

label.secondary-label {
    font-size: 16pt;
    font-weight: bold;
    padding: 12px;
    color: alpha(@theme_fg_color, 0.55);
}

calendar-view {
    font-size: 10pt;
}

calendar-view.header,
label.header {
    font-size: 10pt;
    font-weight: bold;
    color: alpha(@theme_fg_color, 0.55);
}

calendar-view.current,
weekgrid.current {
    background-color: alpha(@accent_bg_color, 0.3);
}

calendar-view:selected {
    color: @accent_color;
    font-weight: bold;
}

popover.events {
    background-color: @theme_bg_color;
    padding: 0;
}

popover.events box {
    border-top-left-radius: 6px;
    border-top-right-radius: 6px;
}

popover.events list {
    background-color: @theme_bg_color;
    border-radius: 6px;
}

popover.events scrolledwindow {
    border-width: 0;
}

popover.events button {
    border-radius: 6px;
    border-top-left-radius: 0;
    border-top-right-radius: 0;
    border-style: solid none none;
    box-shadow: none;
}


/*
 * Event widget
 */

event {
    margin: 1px;
    font-size: 0.9rem;
}

event widget.content {
    margin: 4px;
}

event.timed,
event:not(.slanted):not(.slanted-start):not(.slanted-end) {
    border-radius: 2.5px;
}

event.timed widget.edge {
    border-radius: 2.5px;
    min-width: 5px;
}

event.slanted,
event.slanted-start,
event.slanted-end:dir(rtl) {
    padding-left: 16px;
    border-radius: 0 2.5px 2.5px 0;
}

event.slanted,
event.slanted-end,
event.slanted-start:dir(rtl) {
    padding-right: 16px;
    border-radius: 2.5px 0 0 2.5px;
}

event:not(.timed).color-dark {
    /* Keep in symc with the dark style's event.timed colors */
    color: @light_1;
    outline-color: rgba(0, 0, 0, 0.3);
}

event.timed,
event:not(.timed).color-light {
    color: alpha(@dark_5, 0.8);
    outline-color: rgba(255, 255, 255, 0.5);
}


/* Event Popover */
popover.event-popover,
popover.event-popover > contents {
  padding: 0;
}

.search-viewport {
  background-color: @theme_base_color;
}

/* calendar popover */
.calendar-list {
    background-color: transparent;
}

.calendar-list > list {
    border-radius: 4px;
}

/* Edit dialog's header button */
.sources-button {
    margin-top: 0;
    margin-bottom: 0;
    border-radius: 0;
    border-top-style: none;
    border-bottom-style: none;
}

.sources-button:hover:not(:backdrop) {
    background-image: none;
    text-shadow: none;
}

/* defeats the ugly hover effect of the calendar color dot on buttons */
.calendar-color-image {
    -gtk-icon-filter: none;
}

/* adds a subtle shadow to the calendar color dot when it makes sense */
image.calendar-color-image,
button:active:not(:backdrop) .calendar-color-image,
button:checked:not(:backdrop) .calendar-color-image,
.calendars-list .calendar-color-image:not(:backdrop):not(:disabled),
.calendar-list .calendar-color-image:not(:backdrop):not(:disabled),
.sources-button:not(:backdrop):not(:disabled) .calendar-color-image {
    -gtk-icon-shadow: 0 1px alpha(black, 0.1);
}


/* Date chooser */

/* month/year controls */
datechooser navigator { /* add some space between the two controls */
  margin-right: 6px;
  margin-left: 6px;
  margin-bottom: 6px;
}

datechooser navigator label {
  font-weight: bold;
}

datechooser navigator button {
  padding: 0;
}

/* day names and week numbers*/
datechooser .weeknum,
datechooser .weekday {
  color: @insensitive_fg_color;
  font-size: smaller;
}

/* days */
datechooser button.day {
  font-size: 10pt;
  font-weight: normal;
  margin: 3px;
  min-height: 28px;
  min-width: 28px;
  transition: none;
}

datechooser button.day dot {
  background-color: @theme_fg_color;
  border-radius: 50%;
  min-height: 3px;
  min-width: 3px;
}

datechooser button.day:selected {
  background-color: @accent_bg_color;
  color: @accent_fg_color;
  font-weight: bold;
}

datechooser button.day:selected dot {
  background-color: @accent_fg_color;
}

datechooser button.day.today {
  color: @accent_color;
}

datechooser button.day.today dot {
  background-color: @accent_color;
}

datechooser button.day.today:selected {
  background-color: @accent_bg_color;
  color: @accent_fg_color;
}

datechooser button.day.today:selected dot {
  background-color: @accent_fg_color;
}

datechooser button.day.other-month:not(:hover),
datechooser button.day.other-month:backdrop {
  color: alpha(currentColor, 0.1);
}

datechooser button.day.other-month:not(:hover) dot,
datechooser button.day.other-month:backdrop dot {
  background-color: alpha(currentColor, 0.1);
}

datechooser button.day.other-month:hover:not(:backdrop) {
  color: @insensitive_fg_color;
}

datechooser button.day.other-month:hover:not(:backdrop) dot {
  background-color: @insensitive_fg_color;
}

label.month-name {
    font-size: 16pt;
    font-weight: bold;
    color: @accent_color;
    padding: 12px;
}

/* Week View CSS */

.week-header {
    padding: 0px;
    border-bottom: solid @borders 1px;
}

.week-header .week-number {
    font-size: 16pt;
    font-weight: bold;
    padding: 12px 12px 18px 12px;
    color: alpha(@theme_fg_color, 0.25);
}

.week-header.week-temperature {
    font-size: 10pt;
    font-weight: bold;
    color: alpha(@theme_fg_color, 0.55);
}

.week-header.lines {
    color: alpha(@window_fg_color, 0.15);
}

weekhourbar > label {
    font-size: 10pt;
    padding: 4px 6px;
}

.week-view .lines {
    color: alpha(@window_fg_color, 0.15);
}

weekgrid > widget.now-strip {
    background-color: alpha(@accent_bg_color, 0.8);
    margin: 0 0 0 1px;
    min-height: 2px;
}

weekgrid:selected,
.week-header:selected {
    background-color: alpha(@accent_bg_color, 0.25);
}

weekgrid.dnd, .week-header.dnd {
    background-color: alpha(@accent_bg_color, 0.25);
}

/*
 * Month cell
 */

monthcell {
    border: solid 1px alpha(@borders, 0.3);
    border-width: 1px 0 0 1px;
    background: transparent;
    transition: background-color 200ms;
}

monthcell:selected { background-color: alpha(@accent_bg_color, 0.1); }
monthcell:selected label.day-label { font-weight: bold; }

monthcell:nth-child(7n + 1) { border-left-width: 0; }

monthcell.today { background-color: alpha(@accent_bg_color, 0.25); }
monthcell:selected.today { background-color: alpha(@accent_bg_color, 0.33); }

monthcell.out-of-month {
    background-color: alpha(@theme_bg_color, 0.4);
}

monthcell label {
    color: @theme_fg_color;
    font-size: 0.9rem;
}

monthcell label.day-label {
    font-size: 1rem;
}

monthcell.out-of-month label {
    color: alpha(@theme_fg_color, 0.66);
}

monthcell:hover:not(.out-of-month) {
    background-color: @theme_bg_color;
    transition: background-color 200ms;
}

monthcell button {
    padding: 0 4px;
    border-radius: 0;
    border-bottom: none;
    border-right: none;
}

/*
 * Month popover
 */

monthpopover > box {
  margin: 4px;
  padding: 12px;
  background-color: @popover_bg_color;
}

.notes-section box > textview {
  border-radius: 8px;
  padding: 8px;
}

.notes-section box > textview > text {
  background: none;
}

/* Agenda View CSS */

agenda-view list > row {
  padding: 2px 12px;
}

agenda-view list > label {
  padding: 6px 12px;
}

label.no-events {
  font-style: italic;
}

/*
 * Search
 */

searchbutton > popover > arrow {
  background: none;
  border: none;
}

/*
 * Month selector
 */

datechooser {
  padding: 6px;
}

datechooser .current-week {
  background: alpha(@headerbar_bg_color, 0.7);
  color: @headerbar_fg_color;
  border-radius: 6px;
}

menubutton stack > box {
  border-spacing: 4px;
}
